yakumo.base.GlanceV2Manager

Package yakumo :: Module base :: Class GlanceV2Manager |
[hide private]
[frames] | no frames]

# Class GlanceV2Manager

source code

    object --+
             |
       Manager --+
                 |
                GlanceV2Manager

Known Subclasses:
  - GlanceV2SubManager
  - , glance.v2.image.Manager

Base class for resource managers which don't use _json_resource_key.

Instance Methods | [hide private]
yakumo.base.Resource |
create(self, **kwargs) Create a new resource | source code
yakumo.base.Resource |
get(self, id) Aquire an existing resource object | source code
Inherited from `Manager`: `__init__`, `find`, `find_one`, `get_empty`, `list` Inherited from `Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| _has_extra_attr = `True`
Inherited from `Manager`: `resource_class`, `service_type` Inherited from `Manager` (private): `_attr_mapping`, `_has_detail`, `_hidden_methods`, `_id_attr`, `_json_resource_key`, `_json_resources_key`, `_update_method`, `_url_resource_list_path`, `_url_resource_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, **kwargs) | source code
Create a new resource kwargs: attributes of the resource Returns: yakumo.base.Resource Resource object (empty) Overrides: Manager.create

### get(self, id) | source code
Aquire an existing resource object Parameters: `id` (str) - ID Returns: yakumo.base.Resource Resource object Overrides: Manager.get